@@ -1,31 +1,35 @@
-use std::{error::Error as StdError, fmt, io};
+use std::{
+    error::Error as StdError,
+    fmt::{self, Display},
+    io,
+};
 
 #[derive(Debug)]
 pub enum Error {
     /// Represents any IO error
-    IO(io::Error),
+    IO(io::ErrorKind),
     /// Representes any JSON deserialization or serialization errors
-    JSONError(serde_json::error::Error),
+    JSONError(String),
     ///
-    UnknownJSONValueRef(serde_json::Value),
+    UnknownJSONValueRef(String),
 }
 
 impl From<io::Error> for Error {
     fn from(e: io::Error) -> Self {
-        Self::IO(e)
+        Self::IO(e.kind())
     }
 }
 
 impl From<serde_json::error::Error> for Error {
     fn from(e: serde_json::error::Error) -> Self {
-        Self::JSONError(e)
+        Self::JSONError(e.to_string())
     }
 }
 
-impl fmt::Display for Error {
+impl Display for Error {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match *self {
-            Self::IO(ref e) => write!(f, "{}", e),
+            Self::IO(ref e) => write!(f, "{:?}", e),
             Self::JSONError(ref e) => write!(f, "{}", e),
             Self::UnknownJSONValueRef(ref e) => write!(f, "{}", e),
         }
